@@ -7,7 +7,7 @@ import operator
 import sys
 import csv
 import chardet
-import pandas
+import pandas as pd
 
 # rk.to_txt()
 def to_txt(l, path = 'text_file.txt', overwrite = False, verbose = False):
